# [Common Procedures for Mikrotik RouterBoard Products](https://wiki.openwrt.org/toh/mikrotik/common)
Installing and upgrading OpenWrt on routerboard is a *two step-process*. 
- You first boot a single "initramfs" image of OpenWrt from your DHCP/TFTP server.
- From that running OpenWrt you copy the vmlinux kernel to one flash partition and the root filesystem to another partition. 

## Downloading OpenWrt image
Follow the instructions to download the latest realease (I used Chaos Chalmer 15.05).

## Boot OpenWrt via DHCP/TFTP
Routerboards have a bootloader that can boot and run a .elf file of OpenWrt with initramfs, aka: a single file with the whole OpenWrt package: kernel plus filesystem. A routerboard has at least three flash partitions: bootloader, kernel and root, so this bootloader is preserved even after OpenWrt is installed onto NAND flash later and OpenWrt on flash is booted from the in-flash routerboard bootloader.

### Generic DHCP/TFTP server setup
Never worked for me. Feel free to go with **dnsmasq DHCP/TFTP server**.

### dnsmasq DHCP/TFTP server
- Install the dnsmasq package
```
apt-get update
apt-get install dnsmasq
```
- Follow the instructions to setup a `loader.sh`.

### TFTP boot routerboard from RouterOS
- Open a browser and go to 192.168.88.1
- Change RouterOS settings and reboot it by following the [instructions](https://wiki.openwrt.org/toh/mikrotik/common#from_routeros).
- Connect the routerboard's WAN port to the computer that runs the DHCP/TFTP server you just setup.

## Flash OpenWrt
- After DHCP/TFTP boot of the initramfs, have your PC connected to one of the LAN ports of your routerboard. I used port 2 (the first one after the the WAN port).
- You then first need to go to the web interface http://192.168.1.1 and enter a root password. Afterwards, ssh should work (ssh 192.168.1.1 -l root).
- Follow the [instructions](https://wiki.openwrt.org/toh/mikrotik/common#manually) to flash OpenWrt to the NAND flash of the routerboard manually. The image names might have discrepancies but you can figure it out :).




<!---
I tried to setup DHCP and TFTP manually but never get it worked.

# Setup TFTP server on Ubuntu
[http://processors.wiki.ti.com/index.php/Setting_Up_a_TFTP_Server]

## Install atftp Server in Ubuntu
sudo apt-get install atftpd

## Using atftpd
By default atftpd server starts using inetd so we need to tell atftpd to run as a server directly, not through inetd. Edit /etc/default/atftpd file, a template is shown below:
```
USE_INETD=false
OPTIONS="--tftpd-timeout 300 --bind-address some_ip_address --port 69 --retry-timeout 5 --maxthread 100 /tftpboot"
```
where some_ip_address is the ip you configured to eth0 by `sudo ifconfig eth0 some_ip_address`
Now you need to run the following command
host $ sudo invoke-rc.d atftpd start
### Configure atftpd
host $ sudo mkdir /tftpboot
host $ sudo cp filename /tftpboot
host $ sudo chmod -R 777 /tftpboot
host $ sudo chown -R nobody /tftpboot
host $ sudo /etc/init.d/atftpd restart
### Check if tftp server starts successfully
check the bottom lines of /var/log/syslog
Most likely there is an error message "atftpd: can't bind port some_ip_address:69/udp". This is because inetd service is occupying the port 69.
Run `sudo netstat -nlp | grep 69`, look for something like
'''udp        0      0 0.0.0.0:69              0.0.0.0:*                           1284/inetutils-inet'''
Run `sudo kill 1284` to kill the process.
Run `sudo /etc/init.d/atftpd restart` to restart atftp server.




## Troubleshooting
[http://www.linuxforums.org/forum/ubuntu-linux/192665-installing-atftp.html]
udp        0      0 0.0.0.0:69              0.0.0.0:*                           1284/inetutils-inet
sudo kill 1284


ip -o addr show |awk '$2 !~ /lo/ && $3 ~ /inet$/{print $2,$4}'
ip address is the key
sudo invoke-rc.d atftpd start

Internet Systems Consortium DHCP Server 4.2.4
Copyright 2004-2012 Internet Systems Consortium.
All rights reserved.
For info, please visit https://www.isc.org/software/dhcp/
Wrote 0 deleted host decls to leases file.
Wrote 0 new dynamic host decls to leases file.
Wrote 0 leases to leases file.

No subnet declaration for eth0 (no IPv4 addresses).
** Ignoring requests on eth0.  If this is not what
   you want, please write a subnet declaration
   in your dhcpd.conf file for the network segment
   to which interface eth0 is attached. **


Not configured to listen on any interfaces!
-->

